@@ -17,7 +17,7 @@ use Class::Load qw(load_class);
 use Carp;
 use List::Util qw( uniq);
 
-our $VERSION = '0.054'; # TRIAL VERSION
+our $VERSION = '0.055'; # TRIAL VERSION
 
 use Sub::Quote;
 
@@ -40,9 +40,9 @@ has 'metadata_path' => (
     builder => '_build_metadata_path',
 );
 
-sub _build_metadata_path { 
-    my ($self) = @_; 
-    return $self->bag_path; 
+sub _build_metadata_path {
+    my ($self) = @_;
+    return $self->bag_path;
 }
 
 
@@ -64,9 +64,9 @@ has 'payload_path' => (
     builder => '_build_payload_path',
 );
 
-sub _build_payload_path { 
-    my ($self) = @_; 
-    return $self->bag_path."/data"; 
+sub _build_payload_path {
+    my ($self) = @_;
+    return $self->bag_path."/data";
 }
 
 has 'payload_path_arr' => (
@@ -489,10 +489,10 @@ sub _build_forced_fixity_algorithm {
 
 sub load_plugins {
     my ($self, @plugins) = @_;
- 
-    #p(@plugins); 
-    my $loaded_plugins = $self->plugins;  
-    @plugins = grep { not exists $loaded_plugins->{$_} } @plugins; 
+
+    #p(@plugins);
+    my $loaded_plugins = $self->plugins;
+    @plugins = grep { not exists $loaded_plugins->{$_} } @plugins;
 
     return if @plugins == 0;
     foreach my $plugin (@plugins) {
@@ -567,7 +567,7 @@ sub _verify_XXX_manifests {
             die("Missing files in bag $bagit for algorithm=$alg", join( " file=", @localfiles));
         }
     }
-
+    return 1;
 }
 
 sub _verify_manifests {
@@ -578,6 +578,7 @@ sub _verify_manifests {
         $self->payload_files(),
         $return_all_errors
     );
+    return 1;
 }
 
 sub _verify_tagmanifests {
@@ -590,6 +591,7 @@ sub _verify_tagmanifests {
         \@non_payload_files,
         $return_all_errors
     );
+    return 1;
 }
 
 
@@ -661,7 +663,6 @@ sub create_bagit {
     return 1;
 }
 
-# FIXME: How to add user staff in bag-info.txt?
 sub create_baginfo {
     use POSIX;
     my($self) = @_; # because bag-info.txt allows multiple key-value-entries, hash is replaced
@@ -754,7 +755,7 @@ Archive::BagIt::Base
 
 =head1 VERSION
 
-version 0.054
+version 0.055
 
 =head1 NAME
 
